package remoteproxy;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.Date;

// This class implements a remote proxy to a "real" DateService-implemented object
public class DateProxy implements DateService {
	private ObjectInputStream fromServerStream;
	private ObjectOutputStream toServerStream;
	
	/**
	 * Constructor
	 * @param fromSS socket stream to allow reading from server
	 * @param toSS socket stream to allow writing to server
	 */
	public DateProxy(ObjectInputStream fromSS, ObjectOutputStream toSS ) {
		fromServerStream = fromSS;
		toServerStream = toSS;
	}

	/**
	 * Serialize a request to return the current date from the server
	 * @return the current date as a String
	 */
	@Override
	public String getDate() {
		Message request = new Message(Message.DATEREQUEST);
		String retVal;
		try {
			toServerStream.writeObject(request);
			Message response = (Message)fromServerStream.readObject();
			retVal = response.getValue();
		} catch( ClassNotFoundException e ) {
			retVal = "proxy class cast error; possible JDK incompatibility";
		} catch( IOException e ) {
			retVal = "proxy read error.";
		}
		return retVal;

	}

	/**
	 * Serialize a request to return the current time from the server
	 * @return the current time in ms (after 1/1/1970) as a String
	 */
	@Override
	public String getTime() {
		Message request = new Message(Message.TIMEREQUEST);
		String retVal;
		try {
			toServerStream.writeObject(request);
			Message response = (Message)fromServerStream.readObject();
			retVal = response.getValue();
		} catch( ClassNotFoundException e ) {
			retVal = "proxy class cast error; possible JDK incompatibility";
		} catch( IOException e ) {
			retVal = "proxy read error.";
		}
		return retVal;
	}
}
